@@ -26,6 +26,7 @@
 
 #include "ephy-about-handler.h"
 #include "ephy-prefs.h"
+#include "ephy-reader-handler.h"
 #include "ephy-settings.h"
 #include "ephy-string.h"
 #include "ephy-view-source-handler.h"
@@ -132,6 +133,8 @@ ephy_embed_utils_address_has_web_scheme (const char *address)
                      g_ascii_strncasecmp (address, "ephy-about", colonpos) &&
                      g_ascii_strncasecmp (address, "ephy-resource", colonpos) &&
                      g_ascii_strncasecmp (address, "ephy-source", colonpos) &&
+                     g_ascii_strncasecmp (address, "ephy-reader", colonpos) &&
+                     g_ascii_strncasecmp (address, "ephy-pdf", colonpos) &&
                      g_ascii_strncasecmp (address, "gopher", colonpos) &&
                      g_ascii_strncasecmp (address, "inspector", colonpos) &&
                      g_ascii_strncasecmp (address, "webkit", colonpos));
@@ -215,9 +218,13 @@ is_bang_search (const char *address)
 static gboolean
 is_host_with_port (const char *address)
 {
-  g_auto (GStrv) split = g_strsplit (address, ":", -1);
+  g_auto (GStrv) split = NULL;
   gint64 port = 0;
 
+  if (strchr (address, ' '))
+    return FALSE;
+
+  split = g_strsplit (address, ":", -1);
   if (g_strv_length (split) == 2)
     port = g_ascii_strtoll (split[1], NULL, 10);
 
@@ -394,7 +401,7 @@ ephy_embed_utils_is_no_show_address (const char *address)
     if (!strcmp (address, do_not_show_address[i]))
       return TRUE;
 
-  if (strstr (address, EPHY_VIEW_SOURCE_SCHEME) == address)
+  if (g_str_has_prefix (address, EPHY_VIEW_SOURCE_SCHEME))
     return TRUE;
 
   return FALSE;
