@@ -484,6 +484,7 @@ EphyGSBService *
 ephy_gsb_service_new (const char *api_key,
                       const char *db_path)
 {
+#if ENABLE_GSB
   EphyGSBService *service;
   EphyGSBStorage *storage;
 
@@ -495,6 +496,9 @@ ephy_gsb_service_new (const char *api_key,
   g_object_unref (storage);
 
   return service;
+#else
+  return NULL;
+#endif
 }
 
 static void
